# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 charge_type: pulumi.Input[builtins.str],
                 engine_version: pulumi.Input[builtins.str],
                 master_spec: pulumi.Input[builtins.str],
                 region_id: pulumi.Input[builtins.str],
                 rs_count: pulumi.Input[builtins.int],
                 rs_spec: pulumi.Input[builtins.str],
                 storage_capacity: pulumi.Input[builtins.int],
                 storage_type: pulumi.Input[builtins.str],
                 subnet_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 zone_id: pulumi.Input[builtins.str],
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 cold_storage: Optional[pulumi.Input[builtins.int]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 enable_auth: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_cloud_storage: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 multi_az: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 purchase_months: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[builtins.str] charge_type: 计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        :param pulumi.Input[builtins.str] engine_version: HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        :param pulumi.Input[builtins.str] master_spec: Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        :param pulumi.Input[builtins.str] region_id: 实例所属的地域 ID。
        :param pulumi.Input[builtins.int] rs_count: RegionServer 节点的数量。
        :param pulumi.Input[builtins.str] rs_spec: RegionServer 节点的规格码。
        :param pulumi.Input[builtins.int] storage_capacity: 实例总存储容量，单位：GiB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        :param pulumi.Input[builtins.str] subnet_id: 实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所属的可用区 ID。
        :param pulumi.Input[builtins.bool] auto_renew: 预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        :param pulumi.Input[builtins.int] cold_storage: 实例总容量型存储空间大小，单位 GiB。
        :param pulumi.Input[builtins.str] deletion_protection: 实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        :param pulumi.Input[builtins.bool] enable_auth: 是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        :param pulumi.Input[builtins.bool] enable_cloud_storage: 是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。当前仅支持标准型，取值默认为 Standard。
        :param pulumi.Input[builtins.bool] multi_az: 实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        :param pulumi.Input[builtins.str] project_name: 实例所属的项目名称。
        :param pulumi.Input[builtins.int] purchase_months: 购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        """
        pulumi.set(__self__, "charge_type", charge_type)
        pulumi.set(__self__, "engine_version", engine_version)
        pulumi.set(__self__, "master_spec", master_spec)
        pulumi.set(__self__, "region_id", region_id)
        pulumi.set(__self__, "rs_count", rs_count)
        pulumi.set(__self__, "rs_spec", rs_spec)
        pulumi.set(__self__, "storage_capacity", storage_capacity)
        pulumi.set(__self__, "storage_type", storage_type)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if cold_storage is not None:
            pulumi.set(__self__, "cold_storage", cold_storage)
        if deletion_protection is not None:
            pulumi.set(__self__, "deletion_protection", deletion_protection)
        if enable_auth is not None:
            pulumi.set(__self__, "enable_auth", enable_auth)
        if enable_cloud_storage is not None:
            pulumi.set(__self__, "enable_cloud_storage", enable_cloud_storage)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if multi_az is not None:
            pulumi.set(__self__, "multi_az", multi_az)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if purchase_months is not None:
            pulumi.set(__self__, "purchase_months", purchase_months)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> pulumi.Input[builtins.str]:
        """
        计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> pulumi.Input[builtins.str]:
        """
        HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        """
        return pulumi.get(self, "engine_version")

    @engine_version.setter
    def engine_version(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine_version", value)

    @property
    @pulumi.getter(name="masterSpec")
    def master_spec(self) -> pulumi.Input[builtins.str]:
        """
        Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        """
        return pulumi.get(self, "master_spec")

    @master_spec.setter
    def master_spec(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "master_spec", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Input[builtins.str]:
        """
        实例所属的地域 ID。
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="rsCount")
    def rs_count(self) -> pulumi.Input[builtins.int]:
        """
        RegionServer 节点的数量。
        """
        return pulumi.get(self, "rs_count")

    @rs_count.setter
    def rs_count(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "rs_count", value)

    @property
    @pulumi.getter(name="rsSpec")
    def rs_spec(self) -> pulumi.Input[builtins.str]:
        """
        RegionServer 节点的规格码。
        """
        return pulumi.get(self, "rs_spec")

    @rs_spec.setter
    def rs_spec(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rs_spec", value)

    @property
    @pulumi.getter(name="storageCapacity")
    def storage_capacity(self) -> pulumi.Input[builtins.int]:
        """
        实例总存储容量，单位：GiB。
        """
        return pulumi.get(self, "storage_capacity")

    @storage_capacity.setter
    def storage_capacity(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "storage_capacity", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Input[builtins.str]:
        """
        实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[builtins.str]:
        """
        实例所属的可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="coldStorage")
    def cold_storage(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例总容量型存储空间大小，单位 GiB。
        """
        return pulumi.get(self, "cold_storage")

    @cold_storage.setter
    def cold_storage(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cold_storage", value)

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        """
        return pulumi.get(self, "deletion_protection")

    @deletion_protection.setter
    def deletion_protection(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deletion_protection", value)

    @property
    @pulumi.getter(name="enableAuth")
    def enable_auth(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        """
        return pulumi.get(self, "enable_auth")

    @enable_auth.setter
    def enable_auth(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_auth", value)

    @property
    @pulumi.getter(name="enableCloudStorage")
    def enable_cloud_storage(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        """
        return pulumi.get(self, "enable_cloud_storage")

    @enable_cloud_storage.setter
    def enable_cloud_storage(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_cloud_storage", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]:
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例类型。当前仅支持标准型，取值默认为 Standard。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="multiAz")
    def multi_az(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        """
        return pulumi.get(self, "multi_az")

    @multi_az.setter
    def multi_az(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "multi_az", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="purchaseMonths")
    def purchase_months(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        """
        return pulumi.get(self, "purchase_months")

    @purchase_months.setter
    def purchase_months(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "purchase_months", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_status: Optional[pulumi.Input[builtins.str]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage: Optional[pulumi.Input[builtins.int]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 enable_auth: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_cloud_storage: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]] = None,
                 engine_version: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 master_count: Optional[pulumi.Input[builtins.int]] = None,
                 master_spec: Optional[pulumi.Input[builtins.str]] = None,
                 multi_az: Optional[pulumi.Input[builtins.bool]] = None,
                 primary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 primary_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 purchase_months: Optional[pulumi.Input[builtins.int]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 rs_count: Optional[pulumi.Input[builtins.int]] = None,
                 rs_spec: Optional[pulumi.Input[builtins.str]] = None,
                 standby_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 standby_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 storage_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 used_cold_storage: Optional[pulumi.Input[builtins.int]] = None,
                 used_storage: Optional[pulumi.Input[builtins.float]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[builtins.bool] auto_renew: 预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        :param pulumi.Input[builtins.str] charge_status: 计费状态。取值：Normal：正常。Overdue：欠费。Shutdown：关停。
        :param pulumi.Input[builtins.str] charge_type: 计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        :param pulumi.Input[builtins.int] cold_storage: 实例总容量型存储空间大小，单位 GiB。
        :param pulumi.Input[builtins.str] create_time: 实例创建时间（UTC 时间）。
        :param pulumi.Input[builtins.str] deletion_protection: 实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        :param pulumi.Input[builtins.bool] enable_auth: 是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        :param pulumi.Input[builtins.bool] enable_cloud_storage: 是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        :param pulumi.Input[builtins.str] engine_version: HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。当前仅支持标准型，取值默认为 Standard。
        :param pulumi.Input[builtins.int] master_count: Master 节点个数。单可用区部署，默认包含 2 个 Master 节点。
        :param pulumi.Input[builtins.str] master_spec: Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        :param pulumi.Input[builtins.bool] multi_az: 实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        :param pulumi.Input[builtins.str] primary_subnet_id: 实时主可用区子网 ID。
        :param pulumi.Input[builtins.str] primary_zone_id: 实时主可用区 ID。
        :param pulumi.Input[builtins.str] project_name: 实例所属的项目名称。
        :param pulumi.Input[builtins.int] purchase_months: 购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        :param pulumi.Input[builtins.str] region_id: 实例所属的地域 ID。
        :param pulumi.Input[builtins.int] rs_count: RegionServer 节点的数量。
        :param pulumi.Input[builtins.str] rs_spec: RegionServer 节点的规格码。
        :param pulumi.Input[builtins.str] standby_subnet_id: 实时备可用区子网 ID。
        :param pulumi.Input[builtins.str] standby_zone_id: 实时备可用区 ID。
        :param pulumi.Input[builtins.str] status: 实例当前状态。关于实例状态的更多说明，请参见实例状态说明。
        :param pulumi.Input[builtins.int] storage_capacity: 实例总存储容量，单位：GiB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        :param pulumi.Input[builtins.str] subnet_id: 实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        :param pulumi.Input[builtins.int] used_cold_storage: 实例已使用的容量型存储空间大小，单位 MiB。
        :param pulumi.Input[builtins.float] used_storage: 主实例已使用的存储容量，单位：MiB。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        :param pulumi.Input[builtins.str] vpc_name: 实例所属的私有网络名称。
        :param pulumi.Input[builtins.str] zone_id: 实例所属的可用区 ID。
        :param pulumi.Input[builtins.str] zone_name: 实例所属的可用区名称。
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_status is not None:
            pulumi.set(__self__, "charge_status", charge_status)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if cold_storage is not None:
            pulumi.set(__self__, "cold_storage", cold_storage)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if deletion_protection is not None:
            pulumi.set(__self__, "deletion_protection", deletion_protection)
        if enable_auth is not None:
            pulumi.set(__self__, "enable_auth", enable_auth)
        if enable_cloud_storage is not None:
            pulumi.set(__self__, "enable_cloud_storage", enable_cloud_storage)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if engine_version is not None:
            pulumi.set(__self__, "engine_version", engine_version)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if master_count is not None:
            pulumi.set(__self__, "master_count", master_count)
        if master_spec is not None:
            pulumi.set(__self__, "master_spec", master_spec)
        if multi_az is not None:
            pulumi.set(__self__, "multi_az", multi_az)
        if primary_subnet_id is not None:
            pulumi.set(__self__, "primary_subnet_id", primary_subnet_id)
        if primary_zone_id is not None:
            pulumi.set(__self__, "primary_zone_id", primary_zone_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if purchase_months is not None:
            pulumi.set(__self__, "purchase_months", purchase_months)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if rs_count is not None:
            pulumi.set(__self__, "rs_count", rs_count)
        if rs_spec is not None:
            pulumi.set(__self__, "rs_spec", rs_spec)
        if standby_subnet_id is not None:
            pulumi.set(__self__, "standby_subnet_id", standby_subnet_id)
        if standby_zone_id is not None:
            pulumi.set(__self__, "standby_zone_id", standby_zone_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if storage_capacity is not None:
            pulumi.set(__self__, "storage_capacity", storage_capacity)
        if storage_type is not None:
            pulumi.set(__self__, "storage_type", storage_type)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if used_cold_storage is not None:
            pulumi.set(__self__, "used_cold_storage", used_cold_storage)
        if used_storage is not None:
            pulumi.set(__self__, "used_storage", used_storage)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)
        if zone_name is not None:
            pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        计费状态。取值：Normal：正常。Overdue：欠费。Shutdown：关停。
        """
        return pulumi.get(self, "charge_status")

    @charge_status.setter
    def charge_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_status", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="coldStorage")
    def cold_storage(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例总容量型存储空间大小，单位 GiB。
        """
        return pulumi.get(self, "cold_storage")

    @cold_storage.setter
    def cold_storage(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cold_storage", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例创建时间（UTC 时间）。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        """
        return pulumi.get(self, "deletion_protection")

    @deletion_protection.setter
    def deletion_protection(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deletion_protection", value)

    @property
    @pulumi.getter(name="enableAuth")
    def enable_auth(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        """
        return pulumi.get(self, "enable_auth")

    @enable_auth.setter
    def enable_auth(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_auth", value)

    @property
    @pulumi.getter(name="enableCloudStorage")
    def enable_cloud_storage(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        """
        return pulumi.get(self, "enable_cloud_storage")

    @enable_cloud_storage.setter
    def enable_cloud_storage(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_cloud_storage", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]:
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        """
        return pulumi.get(self, "engine_version")

    @engine_version.setter
    def engine_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine_version", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例类型。当前仅支持标准型，取值默认为 Standard。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="masterCount")
    def master_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Master 节点个数。单可用区部署，默认包含 2 个 Master 节点。
        """
        return pulumi.get(self, "master_count")

    @master_count.setter
    def master_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "master_count", value)

    @property
    @pulumi.getter(name="masterSpec")
    def master_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        """
        return pulumi.get(self, "master_spec")

    @master_spec.setter
    def master_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "master_spec", value)

    @property
    @pulumi.getter(name="multiAz")
    def multi_az(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        """
        return pulumi.get(self, "multi_az")

    @multi_az.setter
    def multi_az(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "multi_az", value)

    @property
    @pulumi.getter(name="primarySubnetId")
    def primary_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实时主可用区子网 ID。
        """
        return pulumi.get(self, "primary_subnet_id")

    @primary_subnet_id.setter
    def primary_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "primary_subnet_id", value)

    @property
    @pulumi.getter(name="primaryZoneId")
    def primary_zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实时主可用区 ID。
        """
        return pulumi.get(self, "primary_zone_id")

    @primary_zone_id.setter
    def primary_zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "primary_zone_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="purchaseMonths")
    def purchase_months(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        """
        return pulumi.get(self, "purchase_months")

    @purchase_months.setter
    def purchase_months(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "purchase_months", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的地域 ID。
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="rsCount")
    def rs_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        RegionServer 节点的数量。
        """
        return pulumi.get(self, "rs_count")

    @rs_count.setter
    def rs_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "rs_count", value)

    @property
    @pulumi.getter(name="rsSpec")
    def rs_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RegionServer 节点的规格码。
        """
        return pulumi.get(self, "rs_spec")

    @rs_spec.setter
    def rs_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rs_spec", value)

    @property
    @pulumi.getter(name="standbySubnetId")
    def standby_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实时备可用区子网 ID。
        """
        return pulumi.get(self, "standby_subnet_id")

    @standby_subnet_id.setter
    def standby_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "standby_subnet_id", value)

    @property
    @pulumi.getter(name="standbyZoneId")
    def standby_zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实时备可用区 ID。
        """
        return pulumi.get(self, "standby_zone_id")

    @standby_zone_id.setter
    def standby_zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "standby_zone_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例当前状态。关于实例状态的更多说明，请参见实例状态说明。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="storageCapacity")
    def storage_capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例总存储容量，单位：GiB。
        """
        return pulumi.get(self, "storage_capacity")

    @storage_capacity.setter
    def storage_capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_capacity", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="usedColdStorage")
    def used_cold_storage(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例已使用的容量型存储空间大小，单位 MiB。
        """
        return pulumi.get(self, "used_cold_storage")

    @used_cold_storage.setter
    def used_cold_storage(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used_cold_storage", value)

    @property
    @pulumi.getter(name="usedStorage")
    def used_storage(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        主实例已使用的存储容量，单位：MiB。
        """
        return pulumi.get(self, "used_storage")

    @used_storage.setter
    def used_storage(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "used_storage", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的私有网络名称。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的可用区名称。
        """
        return pulumi.get(self, "zone_name")

    @zone_name.setter
    def zone_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_name", value)


@pulumi.type_token("bytepluscc:hbase/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage: Optional[pulumi.Input[builtins.int]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 enable_auth: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_cloud_storage: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceEndpointArgs', 'InstanceEndpointArgsDict']]]]] = None,
                 engine_version: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 master_spec: Optional[pulumi.Input[builtins.str]] = None,
                 multi_az: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 purchase_months: Optional[pulumi.Input[builtins.int]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 rs_count: Optional[pulumi.Input[builtins.int]] = None,
                 rs_spec: Optional[pulumi.Input[builtins.str]] = None,
                 storage_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        表格数据库 HBase 版是基于 Apache HBase 提供的全托管 NoSQL 服务，兼容标准 HBase 访问协议，具备低成本存储、高扩展吞吐等优势。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        h_base_instance_demo = bytepluscc.hbase.Instance("HBaseInstanceDemo",
            region_id="cn-beijing",
            multi_az=False,
            zone_id="cn-beijing-a",
            instance_name="HBaseInstanceDemo",
            engine_version="HBase_2.0",
            instance_type="Standard",
            master_spec="hbase.x1.medium",
            rs_count=2,
            rs_spec="hbase.x1.large",
            storage_capacity=20000,
            vpc_id="vpc-rrco37ovjq4gv0x5xxxxx",
            project_name="default",
            charge_type="PrePaid",
            purchase_months=1,
            auto_renew=False,
            subnet_id="subnet-rrwqhg3qzxfkv0x57xxxxx",
            deletion_protection="disabled",
            enable_cloud_storage=False,
            tags=[{
                "key": "env",
                "value": "test",
            }],
            storage_type="HdfsSsd",
            enable_auth=True)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:hbase/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_renew: 预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        :param pulumi.Input[builtins.str] charge_type: 计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        :param pulumi.Input[builtins.int] cold_storage: 实例总容量型存储空间大小，单位 GiB。
        :param pulumi.Input[builtins.str] deletion_protection: 实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        :param pulumi.Input[builtins.bool] enable_auth: 是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        :param pulumi.Input[builtins.bool] enable_cloud_storage: 是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        :param pulumi.Input[builtins.str] engine_version: HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。当前仅支持标准型，取值默认为 Standard。
        :param pulumi.Input[builtins.str] master_spec: Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        :param pulumi.Input[builtins.bool] multi_az: 实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        :param pulumi.Input[builtins.str] project_name: 实例所属的项目名称。
        :param pulumi.Input[builtins.int] purchase_months: 购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        :param pulumi.Input[builtins.str] region_id: 实例所属的地域 ID。
        :param pulumi.Input[builtins.int] rs_count: RegionServer 节点的数量。
        :param pulumi.Input[builtins.str] rs_spec: RegionServer 节点的规格码。
        :param pulumi.Input[builtins.int] storage_capacity: 实例总存储容量，单位：GiB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        :param pulumi.Input[builtins.str] subnet_id: 实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所属的可用区 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        表格数据库 HBase 版是基于 Apache HBase 提供的全托管 NoSQL 服务，兼容标准 HBase 访问协议，具备低成本存储、高扩展吞吐等优势。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        h_base_instance_demo = bytepluscc.hbase.Instance("HBaseInstanceDemo",
            region_id="cn-beijing",
            multi_az=False,
            zone_id="cn-beijing-a",
            instance_name="HBaseInstanceDemo",
            engine_version="HBase_2.0",
            instance_type="Standard",
            master_spec="hbase.x1.medium",
            rs_count=2,
            rs_spec="hbase.x1.large",
            storage_capacity=20000,
            vpc_id="vpc-rrco37ovjq4gv0x5xxxxx",
            project_name="default",
            charge_type="PrePaid",
            purchase_months=1,
            auto_renew=False,
            subnet_id="subnet-rrwqhg3qzxfkv0x57xxxxx",
            deletion_protection="disabled",
            enable_cloud_storage=False,
            tags=[{
                "key": "env",
                "value": "test",
            }],
            storage_type="HdfsSsd",
            enable_auth=True)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:hbase/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 cold_storage: Optional[pulumi.Input[builtins.int]] = None,
                 deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
                 enable_auth: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_cloud_storage: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceEndpointArgs', 'InstanceEndpointArgsDict']]]]] = None,
                 engine_version: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 master_spec: Optional[pulumi.Input[builtins.str]] = None,
                 multi_az: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 purchase_months: Optional[pulumi.Input[builtins.int]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 rs_count: Optional[pulumi.Input[builtins.int]] = None,
                 rs_spec: Optional[pulumi.Input[builtins.str]] = None,
                 storage_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["auto_renew"] = auto_renew
            if charge_type is None and not opts.urn:
                raise TypeError("Missing required property 'charge_type'")
            __props__.__dict__["charge_type"] = charge_type
            __props__.__dict__["cold_storage"] = cold_storage
            __props__.__dict__["deletion_protection"] = deletion_protection
            __props__.__dict__["enable_auth"] = enable_auth
            __props__.__dict__["enable_cloud_storage"] = enable_cloud_storage
            __props__.__dict__["endpoints"] = endpoints
            if engine_version is None and not opts.urn:
                raise TypeError("Missing required property 'engine_version'")
            __props__.__dict__["engine_version"] = engine_version
            __props__.__dict__["instance_name"] = instance_name
            __props__.__dict__["instance_type"] = instance_type
            if master_spec is None and not opts.urn:
                raise TypeError("Missing required property 'master_spec'")
            __props__.__dict__["master_spec"] = master_spec
            __props__.__dict__["multi_az"] = multi_az
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["purchase_months"] = purchase_months
            if region_id is None and not opts.urn:
                raise TypeError("Missing required property 'region_id'")
            __props__.__dict__["region_id"] = region_id
            if rs_count is None and not opts.urn:
                raise TypeError("Missing required property 'rs_count'")
            __props__.__dict__["rs_count"] = rs_count
            if rs_spec is None and not opts.urn:
                raise TypeError("Missing required property 'rs_spec'")
            __props__.__dict__["rs_spec"] = rs_spec
            if storage_capacity is None and not opts.urn:
                raise TypeError("Missing required property 'storage_capacity'")
            __props__.__dict__["storage_capacity"] = storage_capacity
            if storage_type is None and not opts.urn:
                raise TypeError("Missing required property 'storage_type'")
            __props__.__dict__["storage_type"] = storage_type
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["charge_status"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["master_count"] = None
            __props__.__dict__["primary_subnet_id"] = None
            __props__.__dict__["primary_zone_id"] = None
            __props__.__dict__["standby_subnet_id"] = None
            __props__.__dict__["standby_zone_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["used_cold_storage"] = None
            __props__.__dict__["used_storage"] = None
            __props__.__dict__["vpc_name"] = None
            __props__.__dict__["zone_name"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:hbase/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
            charge_status: Optional[pulumi.Input[builtins.str]] = None,
            charge_type: Optional[pulumi.Input[builtins.str]] = None,
            cold_storage: Optional[pulumi.Input[builtins.int]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            deletion_protection: Optional[pulumi.Input[builtins.str]] = None,
            enable_auth: Optional[pulumi.Input[builtins.bool]] = None,
            enable_cloud_storage: Optional[pulumi.Input[builtins.bool]] = None,
            endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceEndpointArgs', 'InstanceEndpointArgsDict']]]]] = None,
            engine_version: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[builtins.str]] = None,
            master_count: Optional[pulumi.Input[builtins.int]] = None,
            master_spec: Optional[pulumi.Input[builtins.str]] = None,
            multi_az: Optional[pulumi.Input[builtins.bool]] = None,
            primary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            primary_zone_id: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            purchase_months: Optional[pulumi.Input[builtins.int]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            rs_count: Optional[pulumi.Input[builtins.int]] = None,
            rs_spec: Optional[pulumi.Input[builtins.str]] = None,
            standby_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            standby_zone_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            storage_capacity: Optional[pulumi.Input[builtins.int]] = None,
            storage_type: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
            used_cold_storage: Optional[pulumi.Input[builtins.int]] = None,
            used_storage: Optional[pulumi.Input[builtins.float]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpc_name: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_renew: 预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        :param pulumi.Input[builtins.str] charge_status: 计费状态。取值：Normal：正常。Overdue：欠费。Shutdown：关停。
        :param pulumi.Input[builtins.str] charge_type: 计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        :param pulumi.Input[builtins.int] cold_storage: 实例总容量型存储空间大小，单位 GiB。
        :param pulumi.Input[builtins.str] create_time: 实例创建时间（UTC 时间）。
        :param pulumi.Input[builtins.str] deletion_protection: 实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        :param pulumi.Input[builtins.bool] enable_auth: 是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        :param pulumi.Input[builtins.bool] enable_cloud_storage: 是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        :param pulumi.Input[builtins.str] engine_version: HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: 实例名称。
        :param pulumi.Input[builtins.str] instance_type: 实例类型。当前仅支持标准型，取值默认为 Standard。
        :param pulumi.Input[builtins.int] master_count: Master 节点个数。单可用区部署，默认包含 2 个 Master 节点。
        :param pulumi.Input[builtins.str] master_spec: Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        :param pulumi.Input[builtins.bool] multi_az: 实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        :param pulumi.Input[builtins.str] primary_subnet_id: 实时主可用区子网 ID。
        :param pulumi.Input[builtins.str] primary_zone_id: 实时主可用区 ID。
        :param pulumi.Input[builtins.str] project_name: 实例所属的项目名称。
        :param pulumi.Input[builtins.int] purchase_months: 购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        :param pulumi.Input[builtins.str] region_id: 实例所属的地域 ID。
        :param pulumi.Input[builtins.int] rs_count: RegionServer 节点的数量。
        :param pulumi.Input[builtins.str] rs_spec: RegionServer 节点的规格码。
        :param pulumi.Input[builtins.str] standby_subnet_id: 实时备可用区子网 ID。
        :param pulumi.Input[builtins.str] standby_zone_id: 实时备可用区 ID。
        :param pulumi.Input[builtins.str] status: 实例当前状态。关于实例状态的更多说明，请参见实例状态说明。
        :param pulumi.Input[builtins.int] storage_capacity: 实例总存储容量，单位：GiB。
        :param pulumi.Input[builtins.str] storage_type: 实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        :param pulumi.Input[builtins.str] subnet_id: 实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        :param pulumi.Input[builtins.int] used_cold_storage: 实例已使用的容量型存储空间大小，单位 MiB。
        :param pulumi.Input[builtins.float] used_storage: 主实例已使用的存储容量，单位：MiB。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        :param pulumi.Input[builtins.str] vpc_name: 实例所属的私有网络名称。
        :param pulumi.Input[builtins.str] zone_id: 实例所属的可用区 ID。
        :param pulumi.Input[builtins.str] zone_name: 实例所属的可用区名称。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["charge_status"] = charge_status
        __props__.__dict__["charge_type"] = charge_type
        __props__.__dict__["cold_storage"] = cold_storage
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["deletion_protection"] = deletion_protection
        __props__.__dict__["enable_auth"] = enable_auth
        __props__.__dict__["enable_cloud_storage"] = enable_cloud_storage
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["engine_version"] = engine_version
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["master_count"] = master_count
        __props__.__dict__["master_spec"] = master_spec
        __props__.__dict__["multi_az"] = multi_az
        __props__.__dict__["primary_subnet_id"] = primary_subnet_id
        __props__.__dict__["primary_zone_id"] = primary_zone_id
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["purchase_months"] = purchase_months
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["rs_count"] = rs_count
        __props__.__dict__["rs_spec"] = rs_spec
        __props__.__dict__["standby_subnet_id"] = standby_subnet_id
        __props__.__dict__["standby_zone_id"] = standby_zone_id
        __props__.__dict__["status"] = status
        __props__.__dict__["storage_capacity"] = storage_capacity
        __props__.__dict__["storage_type"] = storage_type
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["used_cold_storage"] = used_cold_storage
        __props__.__dict__["used_storage"] = used_storage
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_name"] = vpc_name
        __props__.__dict__["zone_id"] = zone_id
        __props__.__dict__["zone_name"] = zone_name
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[builtins.bool]:
        """
        预付费场景下是否自动续费。取值：true：自动续费。false：不自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> pulumi.Output[builtins.str]:
        """
        计费状态。取值：Normal：正常。Overdue：欠费。Shutdown：关停。
        """
        return pulumi.get(self, "charge_status")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> pulumi.Output[builtins.str]:
        """
        计费类型，取值：PostPaid：按量计费（后付费）。PrePaid：包年包月（预付费）。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="coldStorage")
    def cold_storage(self) -> pulumi.Output[builtins.int]:
        """
        实例总容量型存储空间大小，单位 GiB。
        """
        return pulumi.get(self, "cold_storage")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        实例创建时间（UTC 时间）。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> pulumi.Output[builtins.str]:
        """
        实例删除保护功能开关状态。取值范围：enabled：已开启。disabled：未开启。说明关于实例删除保护的更多信息，请参见实例删除保护。
        """
        return pulumi.get(self, "deletion_protection")

    @property
    @pulumi.getter(name="enableAuth")
    def enable_auth(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启登录认证。取值：true：已开启登录认证。false：未开启登录认证。
        """
        return pulumi.get(self, "enable_auth")

    @property
    @pulumi.getter(name="enableCloudStorage")
    def enable_cloud_storage(self) -> pulumi.Output[builtins.bool]:
        """
        是否开通存储型容量，取值：true：开通容量型存储。false：不开通容量型存储。说明容量型存储的详细介绍，请参见冷热分离介绍。仅当 MultiAZ（部署方式）取值为 false（单可用区部署）时，支持冷热分离功能。
        """
        return pulumi.get(self, "enable_cloud_storage")

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output[Sequence['outputs.InstanceEndpoint']]:
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> pulumi.Output[builtins.str]:
        """
        HBase 数据库引擎版本。当前仅支持 HBase 2.0 版本，取值默认为 HBase_2.0。
        """
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[builtins.str]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[builtins.str]:
        """
        实例类型。当前仅支持标准型，取值默认为 Standard。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="masterCount")
    def master_count(self) -> pulumi.Output[builtins.int]:
        """
        Master 节点个数。单可用区部署，默认包含 2 个 Master 节点。
        """
        return pulumi.get(self, "master_count")

    @property
    @pulumi.getter(name="masterSpec")
    def master_spec(self) -> pulumi.Output[builtins.str]:
        """
        Master 节点的规格码。说明关于 Master 节点所支持的规格信息，请参见实例规格。Master 节点数量为固定值，不支持增减。
        """
        return pulumi.get(self, "master_spec")

    @property
    @pulumi.getter(name="multiAz")
    def multi_az(self) -> pulumi.Output[builtins.bool]:
        """
        实例的部署方式，取值：true：多可用区部署。false：单可用区部署。目前仅支持单可用区部署。
        """
        return pulumi.get(self, "multi_az")

    @property
    @pulumi.getter(name="primarySubnetId")
    def primary_subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        实时主可用区子网 ID。
        """
        return pulumi.get(self, "primary_subnet_id")

    @property
    @pulumi.getter(name="primaryZoneId")
    def primary_zone_id(self) -> pulumi.Output[builtins.str]:
        """
        实时主可用区 ID。
        """
        return pulumi.get(self, "primary_zone_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="purchaseMonths")
    def purchase_months(self) -> pulumi.Output[builtins.int]:
        """
        购买时长，单位：月。取值范围如下：1，2，3，4，5，6，7，8，9，12，24，36。说明当 ChargeType 为 PrePaid时，该参数必填。
        """
        return pulumi.get(self, "purchase_months")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的地域 ID。
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="rsCount")
    def rs_count(self) -> pulumi.Output[builtins.int]:
        """
        RegionServer 节点的数量。
        """
        return pulumi.get(self, "rs_count")

    @property
    @pulumi.getter(name="rsSpec")
    def rs_spec(self) -> pulumi.Output[builtins.str]:
        """
        RegionServer 节点的规格码。
        """
        return pulumi.get(self, "rs_spec")

    @property
    @pulumi.getter(name="standbySubnetId")
    def standby_subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        实时备可用区子网 ID。
        """
        return pulumi.get(self, "standby_subnet_id")

    @property
    @pulumi.getter(name="standbyZoneId")
    def standby_zone_id(self) -> pulumi.Output[builtins.str]:
        """
        实时备可用区 ID。
        """
        return pulumi.get(self, "standby_zone_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        实例当前状态。关于实例状态的更多说明，请参见实例状态说明。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageCapacity")
    def storage_capacity(self) -> pulumi.Output[builtins.int]:
        """
        实例总存储容量，单位：GiB。
        """
        return pulumi.get(self, "storage_capacity")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Output[builtins.str]:
        """
        实例的存储类型，取值：HdfsHdd：HDD 文件存储。HdfsSsd：SSD 文件存储。
        """
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的子网 ID。单可用区实例，仅包含一个可用区的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InstanceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="usedColdStorage")
    def used_cold_storage(self) -> pulumi.Output[builtins.int]:
        """
        实例已使用的容量型存储空间大小，单位 MiB。
        """
        return pulumi.get(self, "used_cold_storage")

    @property
    @pulumi.getter(name="usedStorage")
    def used_storage(self) -> pulumi.Output[builtins.float]:
        """
        主实例已使用的存储容量，单位：MiB。
        """
        return pulumi.get(self, "used_storage")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络 ID。说明您可以调用 DescribeVpcs 接口查询可创建 HBase 实例的私有网络信息，包括私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的私有网络名称。
        """
        return pulumi.get(self, "vpc_name")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的可用区名称。
        """
        return pulumi.get(self, "zone_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRuleResult',
    'AwaitableGetRuleResult',
    'get_rule',
    'get_rule_output',
]

@pulumi.output_type
class GetRuleResult:
    """
    A collection of values returned by getRule.
    """
    def __init__(__self__, action_type=None, description=None, domain=None, id=None, listener_id=None, redirect_config=None, rule_id=None, server_group_id=None, tags=None, url=None):
        if action_type and not isinstance(action_type, str):
            raise TypeError("Expected argument 'action_type' to be a str")
        pulumi.set(__self__, "action_type", action_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listener_id and not isinstance(listener_id, str):
            raise TypeError("Expected argument 'listener_id' to be a str")
        pulumi.set(__self__, "listener_id", listener_id)
        if redirect_config and not isinstance(redirect_config, dict):
            raise TypeError("Expected argument 'redirect_config' to be a dict")
        pulumi.set(__self__, "redirect_config", redirect_config)
        if rule_id and not isinstance(rule_id, str):
            raise TypeError("Expected argument 'rule_id' to be a str")
        pulumi.set(__self__, "rule_id", rule_id)
        if server_group_id and not isinstance(server_group_id, str):
            raise TypeError("Expected argument 'server_group_id' to be a str")
        pulumi.set(__self__, "server_group_id", server_group_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="actionType")
    def action_type(self) -> builtins.str:
        """
        转发规则的转发动作。取值如下：Forward：转发至。Redirect：重定向至。
        """
        return pulumi.get(self, "action_type")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        转发规则的描述，默认值为空字符串。规范如下：必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        """
        转发规则的域名。
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> builtins.str:
        """
        监听器ID。
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="redirectConfig")
    def redirect_config(self) -> 'outputs.GetRuleRedirectConfigResult':
        """
        重定向相关配置信息。
        """
        return pulumi.get(self, "redirect_config")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> builtins.str:
        """
        转发规则ID。
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> builtins.str:
        """
        转发规则关联的后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetRuleTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def url(self) -> builtins.str:
        """
        转发规则的URL。
        """
        return pulumi.get(self, "url")


class AwaitableGetRuleResult(GetRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRuleResult(
            action_type=self.action_type,
            description=self.description,
            domain=self.domain,
            id=self.id,
            listener_id=self.listener_id,
            redirect_config=self.redirect_config,
            rule_id=self.rule_id,
            server_group_id=self.server_group_id,
            tags=self.tags,
            url=self.url)


def get_rule(id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRuleResult:
    """
    Data Source schema for Byteplus::CLB::Rule


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:clb/getRule:getRule', __args__, opts=opts, typ=GetRuleResult).value

    return AwaitableGetRuleResult(
        action_type=pulumi.get(__ret__, 'action_type'),
        description=pulumi.get(__ret__, 'description'),
        domain=pulumi.get(__ret__, 'domain'),
        id=pulumi.get(__ret__, 'id'),
        listener_id=pulumi.get(__ret__, 'listener_id'),
        redirect_config=pulumi.get(__ret__, 'redirect_config'),
        rule_id=pulumi.get(__ret__, 'rule_id'),
        server_group_id=pulumi.get(__ret__, 'server_group_id'),
        tags=pulumi.get(__ret__, 'tags'),
        url=pulumi.get(__ret__, 'url'))
def get_rule_output(id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRuleResult]:
    """
    Data Source schema for Byteplus::CLB::Rule


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:clb/getRule:getRule', __args__, opts=opts, typ=GetRuleResult)
    return __ret__.apply(lambda __response__: GetRuleResult(
        action_type=pulumi.get(__response__, 'action_type'),
        description=pulumi.get(__response__, 'description'),
        domain=pulumi.get(__response__, 'domain'),
        id=pulumi.get(__response__, 'id'),
        listener_id=pulumi.get(__response__, 'listener_id'),
        redirect_config=pulumi.get(__response__, 'redirect_config'),
        rule_id=pulumi.get(__response__, 'rule_id'),
        server_group_id=pulumi.get(__response__, 'server_group_id'),
        tags=pulumi.get(__response__, 'tags'),
        url=pulumi.get(__response__, 'url')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetProjectResult',
    'AwaitableGetProjectResult',
    'get_project',
    'get_project_output',
]

@pulumi.output_type
class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, account_id=None, created_time=None, description=None, display_name=None, has_permission=None, id=None, parent_project_name=None, path=None, project_name=None, status=None, updated_time=None):
        if account_id and not isinstance(account_id, int):
            raise TypeError("Expected argument 'account_id' to be a int")
        pulumi.set(__self__, "account_id", account_id)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if has_permission and not isinstance(has_permission, bool):
            raise TypeError("Expected argument 'has_permission' to be a bool")
        pulumi.set(__self__, "has_permission", has_permission)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if parent_project_name and not isinstance(parent_project_name, str):
            raise TypeError("Expected argument 'parent_project_name' to be a str")
        pulumi.set(__self__, "parent_project_name", parent_project_name)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.int:
        """
        账号ID
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        描述
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        展示名
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="hasPermission")
    def has_permission(self) -> builtins.bool:
        """
        是否可见
        """
        return pulumi.get(self, "has_permission")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="parentProjectName")
    def parent_project_name(self) -> builtins.str:
        """
        父项目名称
        """
        return pulumi.get(self, "parent_project_name")

    @property
    @pulumi.getter
    def path(self) -> builtins.str:
        """
        项目路径
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名称
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        启用状态
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            account_id=self.account_id,
            created_time=self.created_time,
            description=self.description,
            display_name=self.display_name,
            has_permission=self.has_permission,
            id=self.id,
            parent_project_name=self.parent_project_name,
            path=self.path,
            project_name=self.project_name,
            status=self.status,
            updated_time=self.updated_time)


def get_project(id: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectResult:
    """
    Data Source schema for Byteplus::IAM::Project


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:iam/getProject:getProject', __args__, opts=opts, typ=GetProjectResult).value

    return AwaitableGetProjectResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        has_permission=pulumi.get(__ret__, 'has_permission'),
        id=pulumi.get(__ret__, 'id'),
        parent_project_name=pulumi.get(__ret__, 'parent_project_name'),
        path=pulumi.get(__ret__, 'path'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_project_output(id: Optional[pulumi.Input[builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectResult]:
    """
    Data Source schema for Byteplus::IAM::Project


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:iam/getProject:getProject', __args__, opts=opts, typ=GetProjectResult)
    return __ret__.apply(lambda __response__: GetProjectResult(
        account_id=pulumi.get(__response__, 'account_id'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        has_permission=pulumi.get(__response__, 'has_permission'),
        id=pulumi.get(__response__, 'id'),
        parent_project_name=pulumi.get(__response__, 'parent_project_name'),
        path=pulumi.get(__response__, 'path'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UnitArgs', 'Unit']

@pulumi.input_type
class UnitArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 parent_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Unit resource.
        :param pulumi.Input[builtins.str] name: 组织单元名称。
        :param pulumi.Input[builtins.str] parent_id: 父单元Id。
        :param pulumi.Input[builtins.str] description: 描述。
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "parent_id", parent_id)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        组织单元名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Input[builtins.str]:
        """
        父单元Id。
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "parent_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _UnitState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_uk: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 depth: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 org_type: Optional[pulumi.Input[builtins.int]] = None,
                 org_unit_id: Optional[pulumi.Input[builtins.str]] = None,
                 owner: Optional[pulumi.Input[builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Unit resources.
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] delete_uk: 删除标识。
        :param pulumi.Input[builtins.str] deleted_time: 删除时间。
        :param pulumi.Input[builtins.int] depth: 深度。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] name: 组织单元名称。
        :param pulumi.Input[builtins.str] org_id: 组织ID。
        :param pulumi.Input[builtins.int] org_type: 组织类型。企业组织： 1
        :param pulumi.Input[builtins.str] org_unit_id: 组织单元ID。
        :param pulumi.Input[builtins.str] owner: 管理员ID。
        :param pulumi.Input[builtins.str] parent_id: 父单元Id。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if delete_uk is not None:
            pulumi.set(__self__, "delete_uk", delete_uk)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if depth is not None:
            pulumi.set(__self__, "depth", depth)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if org_type is not None:
            pulumi.set(__self__, "org_type", org_type)
        if org_unit_id is not None:
            pulumi.set(__self__, "org_unit_id", org_unit_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if parent_id is not None:
            pulumi.set(__self__, "parent_id", parent_id)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deleteUk")
    def delete_uk(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除标识。
        """
        return pulumi.get(self, "delete_uk")

    @delete_uk.setter
    def delete_uk(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "delete_uk", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def depth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        深度。
        """
        return pulumi.get(self, "depth")

    @depth.setter
    def depth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "depth", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织单元名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织ID。
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="orgType")
    def org_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        组织类型。企业组织： 1
        """
        return pulumi.get(self, "org_type")

    @org_type.setter
    def org_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "org_type", value)

    @property
    @pulumi.getter(name="orgUnitId")
    def org_unit_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        组织单元ID。
        """
        return pulumi.get(self, "org_unit_id")

    @org_unit_id.setter
    def org_unit_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_unit_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        管理员ID。
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        父单元Id。
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parent_id", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:organization/unit:Unit")
class Unit(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        企业组织的创建者管理员账号可以新建组织单元来搭建企业的组织结构，对账号进行分组织单元管理。组织单元可以分多个组织单元层级，管理员账号也可属于任意层级的任意组织单元节点。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        organization_unit_demo = bytepluscc.organization.Unit("OrganizationUnitDemo",
            parent_id="735281472xxxx3651635",
            name="OrganizationUnitDemo",
            description="OrganizationUnitDemo description")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:organization/unit:Unit example "org_unit_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] name: 组织单元名称。
        :param pulumi.Input[builtins.str] parent_id: 父单元Id。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UnitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        企业组织的创建者管理员账号可以新建组织单元来搭建企业的组织结构，对账号进行分组织单元管理。组织单元可以分多个组织单元层级，管理员账号也可属于任意层级的任意组织单元节点。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        organization_unit_demo = bytepluscc.organization.Unit("OrganizationUnitDemo",
            parent_id="735281472xxxx3651635",
            name="OrganizationUnitDemo",
            description="OrganizationUnitDemo description")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:organization/unit:Unit example "org_unit_id"
        ```

        :param str resource_name: The name of the resource.
        :param UnitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UnitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UnitArgs.__new__(UnitArgs)

            __props__.__dict__["description"] = description
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if parent_id is None and not opts.urn:
                raise TypeError("Missing required property 'parent_id'")
            __props__.__dict__["parent_id"] = parent_id
            __props__.__dict__["created_time"] = None
            __props__.__dict__["delete_uk"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["depth"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["org_type"] = None
            __props__.__dict__["org_unit_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_time"] = None
        super(Unit, __self__).__init__(
            'bytepluscc:organization/unit:Unit',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_uk: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            depth: Optional[pulumi.Input[builtins.int]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            org_id: Optional[pulumi.Input[builtins.str]] = None,
            org_type: Optional[pulumi.Input[builtins.int]] = None,
            org_unit_id: Optional[pulumi.Input[builtins.str]] = None,
            owner: Optional[pulumi.Input[builtins.str]] = None,
            parent_id: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Unit':
        """
        Get an existing Unit resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] delete_uk: 删除标识。
        :param pulumi.Input[builtins.str] deleted_time: 删除时间。
        :param pulumi.Input[builtins.int] depth: 深度。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] name: 组织单元名称。
        :param pulumi.Input[builtins.str] org_id: 组织ID。
        :param pulumi.Input[builtins.int] org_type: 组织类型。企业组织： 1
        :param pulumi.Input[builtins.str] org_unit_id: 组织单元ID。
        :param pulumi.Input[builtins.str] owner: 管理员ID。
        :param pulumi.Input[builtins.str] parent_id: 父单元Id。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UnitState.__new__(_UnitState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["delete_uk"] = delete_uk
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["depth"] = depth
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["org_type"] = org_type
        __props__.__dict__["org_unit_id"] = org_unit_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["parent_id"] = parent_id
        __props__.__dict__["updated_time"] = updated_time
        return Unit(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deleteUk")
    def delete_uk(self) -> pulumi.Output[builtins.str]:
        """
        删除标识。
        """
        return pulumi.get(self, "delete_uk")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def depth(self) -> pulumi.Output[builtins.int]:
        """
        深度。
        """
        return pulumi.get(self, "depth")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        组织单元名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[builtins.str]:
        """
        组织ID。
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="orgType")
    def org_type(self) -> pulumi.Output[builtins.int]:
        """
        组织类型。企业组织： 1
        """
        return pulumi.get(self, "org_type")

    @property
    @pulumi.getter(name="orgUnitId")
    def org_unit_id(self) -> pulumi.Output[builtins.str]:
        """
        组织单元ID。
        """
        return pulumi.get(self, "org_unit_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[builtins.str]:
        """
        管理员ID。
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Output[builtins.str]:
        """
        父单元Id。
        """
        return pulumi.get(self, "parent_id")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCenResult',
    'AwaitableGetCenResult',
    'get_cen',
    'get_cen_output',
]

@pulumi.output_type
class GetCenResult:
    """
    A collection of values returned by getCen.
    """
    def __init__(__self__, account_id=None, cen_bandwidth_package_ids=None, cen_id=None, cen_name=None, creation_time=None, description=None, id=None, project_name=None, status=None, tags=None, update_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if cen_bandwidth_package_ids and not isinstance(cen_bandwidth_package_ids, list):
            raise TypeError("Expected argument 'cen_bandwidth_package_ids' to be a list")
        pulumi.set(__self__, "cen_bandwidth_package_ids", cen_bandwidth_package_ids)
        if cen_id and not isinstance(cen_id, str):
            raise TypeError("Expected argument 'cen_id' to be a str")
        pulumi.set(__self__, "cen_id", cen_id)
        if cen_name and not isinstance(cen_name, str):
            raise TypeError("Expected argument 'cen_name' to be a str")
        pulumi.set(__self__, "cen_name", cen_name)
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        CEN实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="cenBandwidthPackageIds")
    def cen_bandwidth_package_ids(self) -> Sequence[builtins.str]:
        """
        带宽包ID。
        """
        return pulumi.get(self, "cen_bandwidth_package_ids")

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> builtins.str:
        """
        CEN实例的ID。
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="cenName")
    def cen_name(self) -> builtins.str:
        """
        CEN实例的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填则默认为CEN实例的ID。
        """
        return pulumi.get(self, "cen_name")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        创建CEN实例的时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        CEN实例的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255个字符。不填则默认为空。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        CEN实例所属项目的名称。不填则默认为default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        CEN实例的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetCenTagResult']:
        """
        标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        更新CEN实例的时间。
        """
        return pulumi.get(self, "update_time")


class AwaitableGetCenResult(GetCenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCenResult(
            account_id=self.account_id,
            cen_bandwidth_package_ids=self.cen_bandwidth_package_ids,
            cen_id=self.cen_id,
            cen_name=self.cen_name,
            creation_time=self.creation_time,
            description=self.description,
            id=self.id,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            update_time=self.update_time)


def get_cen(id: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCenResult:
    """
    Data Source schema for Byteplus::CEN::CEN


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cen/getCen:getCen', __args__, opts=opts, typ=GetCenResult).value

    return AwaitableGetCenResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        cen_bandwidth_package_ids=pulumi.get(__ret__, 'cen_bandwidth_package_ids'),
        cen_id=pulumi.get(__ret__, 'cen_id'),
        cen_name=pulumi.get(__ret__, 'cen_name'),
        creation_time=pulumi.get(__ret__, 'creation_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        update_time=pulumi.get(__ret__, 'update_time'))
def get_cen_output(id: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCenResult]:
    """
    Data Source schema for Byteplus::CEN::CEN


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cen/getCen:getCen', __args__, opts=opts, typ=GetCenResult)
    return __ret__.apply(lambda __response__: GetCenResult(
        account_id=pulumi.get(__response__, 'account_id'),
        cen_bandwidth_package_ids=pulumi.get(__response__, 'cen_bandwidth_package_ids'),
        cen_id=pulumi.get(__response__, 'cen_id'),
        cen_name=pulumi.get(__response__, 'cen_name'),
        creation_time=pulumi.get(__response__, 'creation_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        update_time=pulumi.get(__response__, 'update_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetImageResult',
    'AwaitableGetImageResult',
    'get_image',
    'get_image_output',
]

@pulumi.output_type
class GetImageResult:
    """
    A collection of values returned by getImage.
    """
    def __init__(__self__, architecture=None, boot_mode=None, created_at=None, description=None, detection_results=None, id=None, image_id=None, image_name=None, image_owner_id=None, instance_id=None, is_install_run_command_agent=None, is_lts=None, is_support_cloud_init=None, kernel=None, license_type=None, os_name=None, os_type=None, platform=None, platform_version=None, project_name=None, share_permissions=None, share_status=None, size=None, snapshot_group_id=None, snapshot_id=None, snapshots=None, status=None, tags=None, updated_at=None, virtual_size=None, visibility=None):
        if architecture and not isinstance(architecture, str):
            raise TypeError("Expected argument 'architecture' to be a str")
        pulumi.set(__self__, "architecture", architecture)
        if boot_mode and not isinstance(boot_mode, str):
            raise TypeError("Expected argument 'boot_mode' to be a str")
        pulumi.set(__self__, "boot_mode", boot_mode)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if detection_results and not isinstance(detection_results, dict):
            raise TypeError("Expected argument 'detection_results' to be a dict")
        pulumi.set(__self__, "detection_results", detection_results)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if image_name and not isinstance(image_name, str):
            raise TypeError("Expected argument 'image_name' to be a str")
        pulumi.set(__self__, "image_name", image_name)
        if image_owner_id and not isinstance(image_owner_id, str):
            raise TypeError("Expected argument 'image_owner_id' to be a str")
        pulumi.set(__self__, "image_owner_id", image_owner_id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if is_install_run_command_agent and not isinstance(is_install_run_command_agent, bool):
            raise TypeError("Expected argument 'is_install_run_command_agent' to be a bool")
        pulumi.set(__self__, "is_install_run_command_agent", is_install_run_command_agent)
        if is_lts and not isinstance(is_lts, bool):
            raise TypeError("Expected argument 'is_lts' to be a bool")
        pulumi.set(__self__, "is_lts", is_lts)
        if is_support_cloud_init and not isinstance(is_support_cloud_init, bool):
            raise TypeError("Expected argument 'is_support_cloud_init' to be a bool")
        pulumi.set(__self__, "is_support_cloud_init", is_support_cloud_init)
        if kernel and not isinstance(kernel, str):
            raise TypeError("Expected argument 'kernel' to be a str")
        pulumi.set(__self__, "kernel", kernel)
        if license_type and not isinstance(license_type, str):
            raise TypeError("Expected argument 'license_type' to be a str")
        pulumi.set(__self__, "license_type", license_type)
        if os_name and not isinstance(os_name, str):
            raise TypeError("Expected argument 'os_name' to be a str")
        pulumi.set(__self__, "os_name", os_name)
        if os_type and not isinstance(os_type, str):
            raise TypeError("Expected argument 'os_type' to be a str")
        pulumi.set(__self__, "os_type", os_type)
        if platform and not isinstance(platform, str):
            raise TypeError("Expected argument 'platform' to be a str")
        pulumi.set(__self__, "platform", platform)
        if platform_version and not isinstance(platform_version, str):
            raise TypeError("Expected argument 'platform_version' to be a str")
        pulumi.set(__self__, "platform_version", platform_version)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if share_permissions and not isinstance(share_permissions, list):
            raise TypeError("Expected argument 'share_permissions' to be a list")
        pulumi.set(__self__, "share_permissions", share_permissions)
        if share_status and not isinstance(share_status, str):
            raise TypeError("Expected argument 'share_status' to be a str")
        pulumi.set(__self__, "share_status", share_status)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)
        if snapshot_group_id and not isinstance(snapshot_group_id, str):
            raise TypeError("Expected argument 'snapshot_group_id' to be a str")
        pulumi.set(__self__, "snapshot_group_id", snapshot_group_id)
        if snapshot_id and not isinstance(snapshot_id, str):
            raise TypeError("Expected argument 'snapshot_id' to be a str")
        pulumi.set(__self__, "snapshot_id", snapshot_id)
        if snapshots and not isinstance(snapshots, list):
            raise TypeError("Expected argument 'snapshots' to be a list")
        pulumi.set(__self__, "snapshots", snapshots)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if virtual_size and not isinstance(virtual_size, float):
            raise TypeError("Expected argument 'virtual_size' to be a float")
        pulumi.set(__self__, "virtual_size", virtual_size)
        if visibility and not isinstance(visibility, str):
            raise TypeError("Expected argument 'visibility' to be a str")
        pulumi.set(__self__, "visibility", visibility)

    @property
    @pulumi.getter
    def architecture(self) -> builtins.str:
        """
        镜像的架构类型。可以选择amd64（x86计算）、arm64（ARM计算）类型。
        """
        return pulumi.get(self, "architecture")

    @property
    @pulumi.getter(name="bootMode")
    def boot_mode(self) -> builtins.str:
        """
        镜像的启动模式。可以选择BIOS、UEFI类型。
        """
        return pulumi.get(self, "boot_mode")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        镜像创建时间
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        镜像描述。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、英文句号“.”、中文逗号“，”、中文句号“。”和空格。长度限制为0～255个字符。不填默认为空。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="detectionResults")
    def detection_results(self) -> 'outputs.GetImageDetectionResultsResult':
        """
        镜像的检测结果。
        """
        return pulumi.get(self, "detection_results")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        镜像ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> builtins.str:
        """
        镜像名称。必须以字母、汉字开头。只能包含中文、字母、数字、下划线“_”、中划线“-”、英文句号“.”。长度限制为1 ~ 128个字符。
        """
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="imageOwnerId")
    def image_owner_id(self) -> builtins.str:
        """
        镜像所属的账号ID。
        """
        return pulumi.get(self, "image_owner_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例ID。本参数与SnapshotId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="isInstallRunCommandAgent")
    def is_install_run_command_agent(self) -> builtins.bool:
        """
        镜像中是否安装了云助手Agent。
        """
        return pulumi.get(self, "is_install_run_command_agent")

    @property
    @pulumi.getter(name="isLts")
    def is_lts(self) -> builtins.bool:
        """
        公共镜像是否长期维护。
        """
        return pulumi.get(self, "is_lts")

    @property
    @pulumi.getter(name="isSupportCloudInit")
    def is_support_cloud_init(self) -> builtins.bool:
        """
        镜像是否支持Cloud-init。
        """
        return pulumi.get(self, "is_support_cloud_init")

    @property
    @pulumi.getter
    def kernel(self) -> builtins.str:
        """
        镜像的内核版本。
        """
        return pulumi.get(self, "kernel")

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> builtins.str:
        """
        镜像许可证类型。VolcanoEngine：默认，根据您设置的platform，采用官方渠道的许可证。BYOL：自带许可证（BYOL）。
        """
        return pulumi.get(self, "license_type")

    @property
    @pulumi.getter(name="osName")
    def os_name(self) -> builtins.str:
        """
        镜像操作系统的名称。
        """
        return pulumi.get(self, "os_name")

    @property
    @pulumi.getter(name="osType")
    def os_type(self) -> builtins.str:
        """
        操作系统类型。
        """
        return pulumi.get(self, "os_type")

    @property
    @pulumi.getter
    def platform(self) -> builtins.str:
        """
        镜像操作系统的发行版本。可以选择CentOS、Debian、veLinux、Windows Server、Fedora、OpenSUSE、Ubuntu。
        """
        return pulumi.get(self, "platform")

    @property
    @pulumi.getter(name="platformVersion")
    def platform_version(self) -> builtins.str:
        """
        镜像的发行版本。
        """
        return pulumi.get(self, "platform_version")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        资源所属项目。调用接口账号若仅拥有部分项目权限时必须传入有权限的项目信息。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="sharePermissions")
    def share_permissions(self) -> Sequence[builtins.str]:
        """
        镜像共享的账户
        """
        return pulumi.get(self, "share_permissions")

    @property
    @pulumi.getter(name="shareStatus")
    def share_status(self) -> builtins.str:
        """
        镜像共享状态。HasShared：自定义镜像已被共享给其他用户。当自定义镜像未被共享或使用公共镜像时，ShareStatus返回为空。
        """
        return pulumi.get(self, "share_status")

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        镜像大小，单位为GiB。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="snapshotGroupId")
    def snapshot_group_id(self) -> builtins.str:
        """
        快照一致性组ID，表示使用快照一致性组创建自定义镜像。本参数与SnapshotId、InstanceId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_group_id")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        """
        系统盘快照ID，表示使用系统盘快照创建自定义镜像。本参数与InstanceId、SnapshotGroupId参数，三选一必填。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter
    def snapshots(self) -> Sequence['outputs.GetImageSnapshotResult']:
        """
        镜像关联快照的信息。
        """
        return pulumi.get(self, "snapshots")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        镜像的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetImageTagResult']:
        """
        镜像绑定的标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        镜像更新时间
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="virtualSize")
    def virtual_size(self) -> builtins.float:
        """
        镜像大小，单位为Byte。
        """
        return pulumi.get(self, "virtual_size")

    @property
    @pulumi.getter
    def visibility(self) -> builtins.str:
        """
        镜像的可见性。public：公共镜像。private：私有镜像。shared：共享镜像。
        """
        return pulumi.get(self, "visibility")


class AwaitableGetImageResult(GetImageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImageResult(
            architecture=self.architecture,
            boot_mode=self.boot_mode,
            created_at=self.created_at,
            description=self.description,
            detection_results=self.detection_results,
            id=self.id,
            image_id=self.image_id,
            image_name=self.image_name,
            image_owner_id=self.image_owner_id,
            instance_id=self.instance_id,
            is_install_run_command_agent=self.is_install_run_command_agent,
            is_lts=self.is_lts,
            is_support_cloud_init=self.is_support_cloud_init,
            kernel=self.kernel,
            license_type=self.license_type,
            os_name=self.os_name,
            os_type=self.os_type,
            platform=self.platform,
            platform_version=self.platform_version,
            project_name=self.project_name,
            share_permissions=self.share_permissions,
            share_status=self.share_status,
            size=self.size,
            snapshot_group_id=self.snapshot_group_id,
            snapshot_id=self.snapshot_id,
            snapshots=self.snapshots,
            status=self.status,
            tags=self.tags,
            updated_at=self.updated_at,
            virtual_size=self.virtual_size,
            visibility=self.visibility)


def get_image(id: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImageResult:
    """
    Data Source schema for Byteplus::ECS::Image


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:ecs/getImage:getImage', __args__, opts=opts, typ=GetImageResult).value

    return AwaitableGetImageResult(
        architecture=pulumi.get(__ret__, 'architecture'),
        boot_mode=pulumi.get(__ret__, 'boot_mode'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        detection_results=pulumi.get(__ret__, 'detection_results'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        image_name=pulumi.get(__ret__, 'image_name'),
        image_owner_id=pulumi.get(__ret__, 'image_owner_id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        is_install_run_command_agent=pulumi.get(__ret__, 'is_install_run_command_agent'),
        is_lts=pulumi.get(__ret__, 'is_lts'),
        is_support_cloud_init=pulumi.get(__ret__, 'is_support_cloud_init'),
        kernel=pulumi.get(__ret__, 'kernel'),
        license_type=pulumi.get(__ret__, 'license_type'),
        os_name=pulumi.get(__ret__, 'os_name'),
        os_type=pulumi.get(__ret__, 'os_type'),
        platform=pulumi.get(__ret__, 'platform'),
        platform_version=pulumi.get(__ret__, 'platform_version'),
        project_name=pulumi.get(__ret__, 'project_name'),
        share_permissions=pulumi.get(__ret__, 'share_permissions'),
        share_status=pulumi.get(__ret__, 'share_status'),
        size=pulumi.get(__ret__, 'size'),
        snapshot_group_id=pulumi.get(__ret__, 'snapshot_group_id'),
        snapshot_id=pulumi.get(__ret__, 'snapshot_id'),
        snapshots=pulumi.get(__ret__, 'snapshots'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        virtual_size=pulumi.get(__ret__, 'virtual_size'),
        visibility=pulumi.get(__ret__, 'visibility'))
def get_image_output(id: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetImageResult]:
    """
    Data Source schema for Byteplus::ECS::Image


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:ecs/getImage:getImage', __args__, opts=opts, typ=GetImageResult)
    return __ret__.apply(lambda __response__: GetImageResult(
        architecture=pulumi.get(__response__, 'architecture'),
        boot_mode=pulumi.get(__response__, 'boot_mode'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        detection_results=pulumi.get(__response__, 'detection_results'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        image_name=pulumi.get(__response__, 'image_name'),
        image_owner_id=pulumi.get(__response__, 'image_owner_id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        is_install_run_command_agent=pulumi.get(__response__, 'is_install_run_command_agent'),
        is_lts=pulumi.get(__response__, 'is_lts'),
        is_support_cloud_init=pulumi.get(__response__, 'is_support_cloud_init'),
        kernel=pulumi.get(__response__, 'kernel'),
        license_type=pulumi.get(__response__, 'license_type'),
        os_name=pulumi.get(__response__, 'os_name'),
        os_type=pulumi.get(__response__, 'os_type'),
        platform=pulumi.get(__response__, 'platform'),
        platform_version=pulumi.get(__response__, 'platform_version'),
        project_name=pulumi.get(__response__, 'project_name'),
        share_permissions=pulumi.get(__response__, 'share_permissions'),
        share_status=pulumi.get(__response__, 'share_status'),
        size=pulumi.get(__response__, 'size'),
        snapshot_group_id=pulumi.get(__response__, 'snapshot_group_id'),
        snapshot_id=pulumi.get(__response__, 'snapshot_id'),
        snapshots=pulumi.get(__response__, 'snapshots'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        virtual_size=pulumi.get(__response__, 'virtual_size'),
        visibility=pulumi.get(__response__, 'visibility')))
